@@ -103,7 +103,8 @@ macro_rules! root_op_tests {
                 // This test only makes sense if openat2 is supported (i.e., the
                 // default resolver is openat2 -- otherwise the default test
                 // already tested this case).
-                if !*syscalls::OPENAT2_IS_SUPPORTED {
+                // TODO: Drop this?
+                if syscalls::openat2::openat2_is_not_supported() {
                     // skip this test
                     return Ok(());
                 }
@@ -126,7 +127,8 @@ macro_rules! root_op_tests {
                 // This test only makes sense if openat2 is supported (i.e., the
                 // default resolver is openat2 -- otherwise the default test
                 // already tested this case).
-                if !*syscalls::OPENAT2_IS_SUPPORTED {
+                // TODO: Drop this?
+                if syscalls::openat2::openat2_is_not_supported() {
                     // skip this test
                     return Ok(());
                 }
@@ -293,6 +295,7 @@ macro_rules! root_op_tests {
         paste::paste! {
             root_op_tests! {
                 $(#[cfg_attr(not($ignore_meta), ignore)])*
+                #[cfg_attr(not(feature = "_test_race"), ignore)]
                 fn [<$test_name _ $num_threads threads>](root) {
                     utils::check_root_mkdir_all_racing($num_threads, &root, $path, Permissions::from_mode($mode), $expected_result)
                 }
@@ -304,6 +307,7 @@ macro_rules! root_op_tests {
         paste::paste! {
             root_op_tests! {
                 $(#[cfg_attr(not($ignore_meta), ignore)])*
+                #[cfg_attr(not(feature = "_test_race"), ignore)]
                 fn [<$test_name _ $num_threads threads>](root) {
                     utils::check_root_remove_all_racing($num_threads, &root, $path, $expected_result)
                 }
@@ -831,7 +835,7 @@ mod utils {
     use pretty_assertions::{assert_eq, assert_ne};
     use rustix::{
         fs::{Mode, RawMode},
-        process as rustix_process,
+        process::{self as rustix_process, Resource},
     };
 
     fn root_roundtrip<R: RootImpl>(root: R) -> Result<R::Cloned, Error> {
@@ -1316,6 +1320,14 @@ mod utils {
         let root = &root;
         let unsafe_path = unsafe_path.as_ref();
 
+        // Bump the open file limit to the maximum, as this test tends to eat up
+        // a lot of open file handles.
+        rustix_process::setrlimit(Resource::Nofile, {
+            let mut limit = rustix_process::getrlimit(Resource::Nofile);
+            limit.current = limit.maximum;
+            limit
+        })?;
+
         // Do lots of runs to try to catch any possible races.
         let num_retries = 100 + 1_000 / (1 + (num_threads >> 5));
         for _ in 0..num_retries {
@@ -1346,6 +1358,14 @@ mod utils {
         let root = &root;
         let unsafe_path = unsafe_path.as_ref();
 
+        // Bump the open file limit to the maximum, as this test tends to eat up
+        // a lot of open file handles.
+        rustix_process::setrlimit(Resource::Nofile, {
+            let mut limit = rustix_process::getrlimit(Resource::Nofile);
+            limit.current = limit.maximum;
+            limit
+        })?;
+
         // Do lots of runs to try to catch any possible races.
         let num_retries = 100 + 1_000 / (1 + (num_threads >> 5));
         for _ in 0..num_retries {
